program modele_reservoir

    implicit none

    ! parametres globaux
    integer,parameter :: uIn    = 100
    integer,parameter :: uPluie = 150
    integer,parameter :: uOut   = 200
    ! parametres d entree
    integer                  :: nPluie,nCouche
    real(kind=8),allocatable :: apportEau(:)
    real(kind=8)             :: th_cc,drainage,date(6)
    real(kind=8),allocatable :: thCI(:),dz(:)
    ! variable de sortie
    real(kind=8),allocatable  :: th(:)
    ! variables locales
    integer            :: i,j
    real(kind=8)       :: apportActu,stockDispo
    character(len=100) :: nomRepIn,nomRepOut

    ! lecture en argument du repertoire de travail
    if (iargc().NE.2) then
        print'("Erreur : entrer en argument le repertoire de travail")'
        stop
    end if

    call getarg(1,nomRepIn)
    call getarg(2,nomRepOut)
    ! lecture du fichier pluie
    open(uPluie,file=trim(nomRepIn)//'/Pluvio_3_1997_06_05.txt',status='old')
    nPluie = 541
    allocate(apportEau(nPluie))
    do i=1,nPluie
        read(uPluie,*) date(1:6),apportEau(i)
    end do
    close(uIn)

    ! lecture des parametres
    open(uIn,file=trim(nomRepIn)//'/input.txt',status='old')
    read(uIn,*) th_cc
    read(uIn,*) nCouche
    allocate(thCI(nCouche),dz(nCouche),th(nCouche))
    do i=1,nCouche
        read(uIn,*) j,dz(j),thCI(j)
    end do
    close(uIn)

    ! calculs : repartition de l'apport sur les couches de sol
    drainage = 0d0
    th       = 0d0
    print'("pas de temps  |  apport  |  stock   | drainage |")'
    do i=1,nPluie
        apportActu = apportEau(i)
        do j=1,nCouche
            stockDispo = (th_cc - thCI(j)) * dz(j)
            if (apportActu.GE.stockDispo) then
                th(j)      = th_cc
                apportActu = apportActu - stockDispo
            else
                th(j)      = thCI(j) + apportActu/dz(j)
                apportActu = 0.0
            end if
        end do
        drainage = drainage + apportActu
        thCI     = th
        print'(i14,"|",3(f10.4,"|"))', i,apportEau(i),sum(th*dz),drainage
    end do

    ! enregistrement des resultats
    open(uOut,file=trim(nomRepOut)//'/out_fortran.txt',status='replace')
    do i=1,nCouche
        write(uOut,*) i,dz(i),th(i)
    end do
    write(uOut,*) drainage
    close(uOut)

end program modele_reservoir
